==> qtjambi-webenginecore-6.5.1-sources.jar: io/qt/webengine/core/QWebEngineFindTextResult.java <==
package io.qt.webengine.core;

import io.qt.*;


/**
 * <p>Encapsulates the result of a string search on a page</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/qwebenginefindtextresult.html">QWebEngineFindTextResult</a></p>
 */
public class QWebEngineFindTextResult extends QtObject
    implements java.lang.Cloneable
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QWebEngineFindTextResult.class);
    
    
    public QWebEngineFindTextResult(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QWebEngineFindTextResult instance);
    
    public QWebEngineFindTextResult(io.qt.webengine.core.@NonNull QWebEngineFindTextResult other){
        super((QPrivateConstructor)null);
        initialize_native(this, other);
    }
    
    private native static void initialize_native(QWebEngineFindTextResult instance, io.qt.webengine.core.QWebEngineFindTextResult other);
    
    /**
     * <p>Kotlin property getter. In Java use {@link #activeMatch()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final int getActiveMatch() {
        return activeMatch();
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebenginefindtextresult.html#activeMatch-prop">QWebEngineFindTextResult::activeMatch()const</a></p>
     */
    @QtPropertyReader(name="activeMatch")
    @QtPropertyConstant
    @QtUninvokable
    public final int activeMatch(){
        return activeMatch_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native int activeMatch_native_constfct(long __this__nativeId);
    
    /**
     * <p>Kotlin property getter. In Java use {@link #numberOfMatches()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final int getNumberOfMatches() {
        return numberOfMatches();
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebenginefindtextresult.html#numberOfMatches-prop">QWebEngineFindTextResult::numberOfMatches()const</a></p>
     */
    @QtPropertyReader(name="numberOfMatches")
    @QtPropertyConstant
    @QtUninvokable
    public final int numberOfMatches(){
        return numberOfMatches_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native int numberOfMatches_native_constfct(long __this__nativeId);
    
    /**
     * @deprecated Use {@link #assign(io.qt.webengine.core.QWebEngineFindTextResult)} instead.
     */
    @Deprecated
    @QtUninvokable
    public final void set(io.qt.webengine.core.@NonNull QWebEngineFindTextResult other) {
        assign(other);
    }
    
    @QtUninvokable
    public final void assign(io.qt.webengine.core.@NonNull QWebEngineFindTextResult other){
        assign_native_cref_QWebEngineFindTextResult(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(other));
    }
    
    @QtUninvokable
    private native void assign_native_cref_QWebEngineFindTextResult(long __this__nativeId, long other);
    
    @QtUninvokable
    private final boolean operator_equal(io.qt.webengine.core.@NonNull QWebEngineFindTextResult arg2){
        return operator_equal_native_cref_QWebEngineFindTextResult(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(arg2));
    }
    
    @QtUninvokable
    private native boolean operator_equal_native_cref_QWebEngineFindTextResult(long __this__nativeId, long arg2);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @NativeAccess
    protected QWebEngineFindTextResult(QPrivateConstructor p) { super(p); } 
    

    @Override
    @QtUninvokable
    public boolean equals(Object other) {
        if (other instanceof io.qt.webengine.core.QWebEngineFindTextResult) {
            return operator_equal((io.qt.webengine.core.QWebEngineFindTextResult) other);
        }

        return false;
    }


    @QtUninvokable
    @Override
    public int hashCode() {
        return hashCode_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    @QtUninvokable
    private native static int hashCode_native(long __this_nativeId);
    
    /**
     * <p>Creates and returns a copy of this object.</p>
     */
    @QtUninvokable
    @Override
    public QWebEngineFindTextResult clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private static native QWebEngineFindTextResult clone_native(long __this_nativeId);
}

==> qtjambi-webenginecore-6.5.4-sources.jar: io/qt/webengine/core/QWebEngineFindTextResult.java <==
package io.qt.webengine.core;

import io.qt.*;


/**
 * <p>Encapsulates the result of a string search on a page</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qwebenginefindtextresult.html">QWebEngineFindTextResult</a></code></p>
 */
public class QWebEngineFindTextResult extends QtObject
    implements java.lang.Cloneable
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QWebEngineFindTextResult.class);
    
    
    /**
     * <p>See <code>QWebEngineFindTextResult::<wbr/>QWebEngineFindTextResult()</code></p>
     */
    public QWebEngineFindTextResult(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QWebEngineFindTextResult instance);
    
    /**
     * <p>See <code>QWebEngineFindTextResult::<wbr/>QWebEngineFindTextResult(QWebEngineFindTextResult)</code></p>
     */
    public QWebEngineFindTextResult(io.qt.webengine.core.@NonNull QWebEngineFindTextResult other){
        super((QPrivateConstructor)null);
        initialize_native(this, other);
    }
    
    private native static void initialize_native(QWebEngineFindTextResult instance, io.qt.webengine.core.QWebEngineFindTextResult other);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qwebenginefindtextresult.html#activeMatch-prop">QWebEngineFindTextResult::<wbr/>activeMatch()const</a></code></p>
     */
    @QtPropertyReader(name="activeMatch")
    @QtPropertyConstant
    @QtUninvokable
    public final int activeMatch(){
        return activeMatch_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native int activeMatch_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qwebenginefindtextresult.html#numberOfMatches-prop">QWebEngineFindTextResult::<wbr/>numberOfMatches()const</a></code></p>
     */
    @QtPropertyReader(name="numberOfMatches")
    @QtPropertyConstant
    @QtUninvokable
    public final int numberOfMatches(){
        return numberOfMatches_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native int numberOfMatches_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>QWebEngineFindTextResult::<wbr/>operator=(QWebEngineFindTextResult)</code></p>
     */
    @QtUninvokable
    public final void assign(io.qt.webengine.core.@NonNull QWebEngineFindTextResult other){
        assign_native_cref_QWebEngineFindTextResult(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(other));
    }
    
    @QtUninvokable
    private native void assign_native_cref_QWebEngineFindTextResult(long __this__nativeId, long other);
    
    /**
     * <p>See <code>operator==(QWebEngineFindTextResult,<wbr/>QWebEngineFindTextResult)</code></p>
     */
    @QtUninvokable
    public final boolean equals(io.qt.webengine.core.@NonNull QWebEngineFindTextResult arg2){
        return equals_native_cref_QWebEngineFindTextResult(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(arg2));
    }
    
    @QtUninvokable
    private native boolean equals_native_cref_QWebEngineFindTextResult(long __this__nativeId, long arg2);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QWebEngineFindTextResult(QPrivateConstructor p) { super(p); } 
    

    /**
     * <p>See <code>operator==(QWebEngineFindTextResult,<wbr/>QWebEngineFindTextResult)</code></p>
     */
    @Override
    @QtUninvokable
    public boolean equals(Object other) {
        if (other instanceof io.qt.webengine.core.QWebEngineFindTextResult) {
            return equals((io.qt.webengine.core.QWebEngineFindTextResult) other);
        }

        return false;
    }


    /**
     * Returns the objects's hash code computed by <code>qHash(QWebEngineFindTextResult)</code>.
     */
    @QtUninvokable
    @Override
    public int hashCode() {
        return hashCode_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    @QtUninvokable
    private native static int hashCode_native(long __this_nativeId);
    
    /**
     * <p>Creates and returns a copy of this object.</p>
     */
    @QtUninvokable
    @Override
    public QWebEngineFindTextResult clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private static native QWebEngineFindTextResult clone_native(long __this_nativeId);
    
    /**
     * @hidden
     * <p>Kotlin property getter. In Java use {@link #activeMatch()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final int getActiveMatch() {
        return activeMatch();
    }
    
    /**
     * @hidden
     * <p>Kotlin property getter. In Java use {@link #numberOfMatches()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final int getNumberOfMatches() {
        return numberOfMatches();
    }
    
    /**
     * @deprecated Use {@link #assign(io.qt.webengine.core.QWebEngineFindTextResult)} instead.
     */
    @Deprecated
    @QtUninvokable
    public final void set(io.qt.webengine.core.@NonNull QWebEngineFindTextResult other) {
        assign(other);
    }
}
